@@ -89,17 +89,6 @@ def fuzzspecs(specdir = inspecdir):
     '''
     
     print ("\n\n----Done Fuzzing all specs -----------------------------------------\n\n")
-    from cvdastwrapper import apispecs
-    apispecs.apispeclist = specnames
-    
-    f = open(runconfig.genspeclistpyfname, "w+")
-    f.write("#!/usr/bin/python \n")
-    f.write("apispeclist=%s" %(specnames))
-    f.close()
-
-    with open('specslist.json', 'w') as fj:
-        json.dump({'specs': specnames}, fj)
-
     #print ("\n You can update runconfig.py with this complete API spec list: \n\n apispeclist=%s \n\n" % specnames)
     
 '''end of fuzzspecs'''
